#include "pico/stdlib.h"
#include <stdio.h>
#include "hardware/pwm.h"
#include "hardware/clocks.h"
#include "../xiao_rp2040.h"

#define PIN_BUZZER D8

int main() {
  stdio_init_all();

  // Tell the pin that the PWM is in charge of its value.
  gpio_set_function(PIN_BUZZER, GPIO_FUNC_PWM);

  // Figure out which slice we just connected to the LED pin
  uint slice_num = pwm_gpio_to_slice_num(PIN_BUZZER);

  // Get some sensible defaults for the slice configuration. By default, the
  // counter is allowed to wrap over its maximum range (0 to 2**16-1)
  pwm_config config = pwm_get_default_config();

  // Set divider, reduces counter clock to sysclock/this value
  // In this case it is 400 Hz
  pwm_config_set_clkdiv(&config, 4.77f);
  // Load the configuration into our PWM slice, and set it running.
  pwm_init(slice_num, &config, true);

  // set the level to half of the counter to get a 50% duty cycle.
  pwm_set_gpio_level(PIN_BUZZER, 65356/2);

  while (1) {
    tight_loop_contents();
  }
}
