(defparameter *y-v-low* nil
  "The y-coordinate of the pixel for a low voltage")
(defparameter *v-low* nil
  "The value for the low voltage")

(defparameter *y-v-high* nil
  "The y-coordinate of the pixel for a voltage of 7.86")
(defparameter *v-high* nil
  "The value for a high voltage")


(defparameter *y-i-high* nil
  "The y-coordinate of the pixel for a high current I")
(defparameter *i-high* nil
  "The value for a high current")


(defparameter *y-i-low* nil
  "The y-coordinate of the pixel for a low current I")
(defparameter *i-low* nil
  "The value for the low current.")

(defun compute-value (value-low y-low value-high y-high y)
  "Given a y-coordinate, compute the value.

The value is computed according to low and high values and the corresponding y
coordinates of those low and high values."
  (let ((range-y (- y-high y-low))
	(range-val (- value-high value-low))
	(y-corrected (- y y-low)))
    (+ (/ (* y-corrected range-val) range-y)
       value-low)))

(defun power-consumption (y-Vs y-Is)
  "compute the power consumption over voltage and current samples.

The voltage and current samples are expressed in terms of y-coordinates.  From
this we compute the actual values, compute the power for each sample and sum it
acquire the power consumption."
  (let* ((vs (mapcar #'(lambda (y)
			(compute-value *v-low* *y-v-low* *v-high* *y-v-high* y))
		    y-Vs))
	 (is (mapcar #'(lambda (y)
			(compute-value *i-low* *y-i-low* *i-high* *y-i-high* y))
		    y-Is))
	 (ps (mapcar #'* vs is)))
    (reduce #'+ ps)))

(defun print-result (start end power-cons)
  "Print the result of the power consumption from start to end."
  (format t "Power consumption over ~a to ~a s: ~a J~%"
	  start end power-cons))

;; Graph 1
;; (let ((*y-v-low* 760)
;;       (*v-low* 6.86)
;;       (*y-v-high* 59)
;;       (*v-high* 7.22)

;;       (*y-i-high* 123)
;;       (*i-high* 1.8)
;;       (*y-i-low* 797)
;;       (*i-low* 0))

;;   (defparameter *y-v-no-load* '(79 79 156 98 117 137 98 117 176 79))
;;   (defparameter *y-i-no-load* '(770 767 743 776 774 775 772 771 744 763))

;;   (defparameter *y-v-load* '(59 98 69 69 137 137 779 70 117 64))
;;   (defparameter *y-i-load* '(767 106 768 678 744 767 68 772 764 766))

;;   (print-result 10 20 (power-consumption *y-v-no-load* *y-i-no-load*))
;;   (print-result 70 80 (power-consumption *y-v-load* *y-i-load*)))

;; Graph servo
(let ((*y-v-low* 762)
      (*v-low* 6.8)
      (*y-v-high* 93)
      (*v-high* 7.2)

      (*y-i-high* 134)
      (*i-high* 1.8)
      (*y-i-low* 797)
      (*i-low* 0))

  (defparameter *y-v-no-load* '(76 93 93 93 76 76 93 93 76 93))
  (defparameter *y-i-no-load* '(775 766 774 777 761 763 775 775 774 770))

  (defparameter *y-v-load* '(59 93 76 59 126 126 679 76 109 76))
  (defparameter *y-i-load* '(767 106 768 678 744 767 59 772 764 766))

  (print-result 30 40 (power-consumption *y-v-no-load* *y-i-no-load*))
  (print-result 70 80 (power-consumption *y-v-load* *y-i-load*)))

;; Graph stepper
(let ((*y-v-low* 674)
      (*v-low* 8)
      (*y-v-high* 93)
      (*v-high* 12)

      (*y-i-high* 140)
      (*i-high* 0.9)
      (*y-i-low* 746)
      (*i-low* 0.1))

  (defparameter *y-v* '(91 91 95 93 91 69 282 136 90 91))
  (defparameter *y-i* '(768 702 306 764 779 114 63 702 768 750))

  (print-result 50 60 (power-consumption *y-v* *y-i*)))
